h5pydantic is a Pydantic based library aimed at making it easier for
scientists to organise their HDF5 files, by writing Python models of
their experiments.

The library is inspired by the need of the Australian Synchrotron
during the commissioning of our new beamlines under the BRIGHT
program. The library is currently under development.
